
/* Chrysalide - Outil d'analyse de fichiers binaires
 * constants.c - ajout des constantes liées au coeur du programme
 *
 * Copyright (C) 2020 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "constants.h"


#include <core/logs.h>


#include "../helpers.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont le dictionnaire est à compléter.        *
*                                                                             *
*  Description : Définit les constantes pour les types de messages.           *
*                                                                             *
*  Retour      : true en cas de succès de l'opération, false sinon.           *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool define_core_logs_constants(PyObject *module)
{
    bool result;                            /* Bilan à retourner           */
    PyObject *values;                       /* Groupe de valeurs à établir */

    values = PyDict_New();

    result = add_const_to_group(values, "INFO", LMT_INFO);
    if (result) result = add_const_to_group(values, "PROCESS", LMT_PROCESS);
    if (result) result = add_const_to_group(values, "WARNING", LMT_WARNING);
    if (result) result = add_const_to_group(values, "BAD_BINARY", LMT_BAD_BINARY);
    if (result) result = add_const_to_group(values, "LMT_ERROR", LMT_ERROR);
    if (result) result = add_const_to_group(values, "EXT_ERROR", LMT_EXT_ERROR);
    if (result) result = add_const_to_group(values, "COUNT", LMT_COUNT);

    if (!result)
    {
        Py_DECREF(values);
        goto exit;
    }

    result = attach_constants_group_to_module(module, false, "LogMessageType", values,
                                              "Available types for log messages.");

 exit:

    return result;

}
